/* -*- linux-c -*- (Autoset linux indent style when using emacs) */

/*****************************************************************************
 *
 * Copyright 1999 Digi International (www.digi.com)
 *     Jeff Randall <Jeff_Randall@digi.com>
 *     James Puzzo  <jamesp@digi.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, EXPRESS OR IMPLIED; without even the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *****************************************************************************/

/* $Id: dgrp_driver.c,v 1.22 2001/11/02 06:58:23 jamesp Exp $ */

static char *version = DIGI_VERSION;

#include <linux/module.h>

#include "linux_ver_fix.h"

/*
 *	Driver specific includes
 */
#include <linux/tty.h>

/*
 *  PortServer includes
 */
#include "dgrp_common.h"
#include "dgrp_proc.h"


MODULE_AUTHOR("Digi International, http://www.digi.com");
MODULE_DESCRIPTION("RealPort driver for Digi's ethernet-based serial connectivity product line");
MODULE_SUPPORTED_DEVICE("dgrp");

#if defined(MODULE_LICENSE)
MODULE_LICENSE("GPL");
#endif

/*
 * insmod command line overrideable parameters
 *
 * NOTE: we use a set of macros to create the variables, which allows
 * us to specify the variable type, name, initial value, and description.
 * This makes things work swell for both 2.0 and 2.1+ kernels.
 *
 * NOTE: these are _only_ the "external" versions of these variables.
 * These are copied (via the initialization procedure) to the internal
 * versions, which have a GLBL prefix (as defined by dgrp_common.h).
 *
 */

PARM_INT(rawreadok,		1,	"Bypass flip buffers on input");

#if ALLOW_ALT_FAIL_OPEN
PARM_INT(alt_fail_open,	ALT_FAIL_OPEN_DEFAULT,
                        "Enable alternate failed open behavior");
#endif

PARM_INT(net_debug,		0,	"Turn on/off net debugging");
PARM_INT(mon_debug,		0,	"Turn on/off mon debugging");
PARM_INT(comm_debug,		0,	"Turn on/off comm debugging");
PARM_INT(tty_debug,		0,	"Turn on/off tty debugging");
PARM_INT(ports_debug,	0,	"Turn on/off debugging of /proc/dgrp/ports");


/************************************************************************/
/*									*/
/*	Initialization and downloading of board				*/
/*									*/
/************************************************************************/

/*
 *	Module unload.  This is where it all ends.
 */
void
cleanup_module(void)
{

	/*
	 *	Attempting to free resources in backwards
	 *	order of allocation, in case that helps
	 *	memory pool fragmentation.
	 */
	dgrp_proc_unregister_all();

	/*
	 *  Free any currently allocated PortServer structures
	 */
	nd_struct_cleanup();
}

/*
 *	Module load.  This is where it all starts.
 */
int
init_module(void)
{
	int	rc=0;

	dbg_trace(("Digi RealPort driver version: %s\n", version));

	/*
	 *  Initialize the hash tables for the PortServer structures
	 */
	nd_struct_init();

	/* 
	 *  Copy the PARM variable to our driver globals
	 */
	GLBL(rawreadok) = rawreadok;
	GLBL(net_debug) = net_debug;
	GLBL(mon_debug) = mon_debug;
	GLBL(tty_debug) = tty_debug;
	GLBL(comm_debug) = comm_debug;
	GLBL(ports_debug) = ports_debug;

#if ALLOW_ALT_FAIL_OPEN
	GLBL(alt_fail_open) = alt_fail_open;
#endif

	dgrp_proc_register_basic();

	return (rc);
}
