/* -*- linux-c -*- (Autoset linux indent style when using emacs) */

/*****************************************************************************
 *
 * Copyright 1999 Digi International (www.digi.com)
 *     James Puzzo <jamesp@digi.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, EXPRESS OR IMPLIED; without even the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *****************************************************************************/

/****************************************************************************
 *
 *  Filename:
 *
 *     $Id: linux_ver_fix.h,v 1.15 2001/10/16 23:11:09 jamesp Exp $
 *
 *  Description:
 *
 *     This header provides a number of common includes and definitions
 *     which assist in writing C code to be built on multiple versions of
 *     Linux.
 *
 *  Author:
 *
 *     James A. Puzzo
 *
 *****************************************************************************/

#ifndef __LINUX_VER_FIX_H
#define __LINUX_VER_FIX_H

#ifndef __KERNEL__
#  define __KERNEL__
#endif
#ifndef MODULE
#  define MODULE
#endif

#define __NO_VERSION__
#include <linux/module.h> /* get MOD_DEC_USE_COUNT, not the version string */
#include <linux/version.h>

/*
 *	Additional types needed by header files
 */
typedef unsigned char	uchar;
#define	TRUE		1
#define FALSE		0

/*
 *	typedef's that are missing from Digi header files.  Sigh.
 */
typedef struct digiheader 	DIGIHDR;

/*
 *	typedef's that are missing from Linux header files.  Sigh.
 */
typedef struct tty_driver	TTYDRIVER;
typedef struct tty_struct	TTY;
typedef struct file		FILE;
typedef struct termios		TERMIOS;
typedef struct semaphore	SEMAPHORE;
typedef struct proc_dir_entry	PDE;

#if !defined(KERNEL_VERSION) /* defined in version.h in later kernels */
# define KERNEL_VERSION(a,b,c)  (((a) << 16) + ((b) << 8) + (c))
#endif

/*
 *	Some API's changed at linux version 2.1.x.  I'm not sure exactly
 *	when they changed during the 2.1.x development, but it doesn't
 *	matter to us.  Create some macros to preserve compatibility.
 *
 *	Here you can see what has changed between 2.0 and 2.1+. If you
 *	are reading/writing this file, you should be well aware of these
 *	macros or you won't be able to follow whats going on.  The
 *	alternative was #ifdef spaghetti.
 *
 * Of course, even more changed in the 2.3.x timeframe... we only
 * really care about later 2.3 and 2.4, so we ignore the fact that
 * some of these code changes may not have occured yet in early 2.3.
 */
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,0)

	#include <asm/uaccess.h>
	#include <linux/poll.h>

	#define IOREMAP(ADDR, LEN)		ioremap(ADDR, LEN)
	#define IOUNMAP(ADDR)			iounmap(ADDR)
	#define COPY_FROM_USER(DST,SRC,LEN)	copy_from_user(DST,SRC,LEN)
	#define COPY_TO_USER(DST,SRC,LEN)	copy_to_user(DST,SRC,LEN)
	#define GET_USER(A1,A2)			get_user(A1,(unsigned int *)A2)
	#define PUT_USER(A1,A2)			put_user(A1,(unsigned long *)A2)

	#define	READ_PROTO \
		struct file *file, char *buf, size_t count, loff_t *ppos
	#define	READ_ARGS	file, buf, count, ppos
	#define	READ_RETURN_T	ssize_t

	#define	WRITE_PROTO \
		struct file *file, const char *buf, size_t count, loff_t *ppos
	#define	WRITE_ARGS	file, buf, count, ppos
	#define	WRITE_RETURN_T	ssize_t

	#define SELECT_NAME	poll
	#define SELECT_PROTO \
		struct file *file, struct poll_table_struct *table
	#define SELECT_ARGS	file, table
	#define SELECT_RETURN_T	unsigned int

	#define	CLOSE_RETURN_T	int
	#define	CLOSE_RETURN(X)	return(X)

	#define	PARM_I_RDEV	file->f_dentry->d_inode->i_rdev
	#define	PARM_GEN_IP	file->f_dentry->d_inode->u.generic_ip
	#define PTR_POS()	ppos
	#define	GET_POS()	*ppos
	#define	ADD_POS(AMT)	*ppos += (AMT)
	#define	SET_POS(AMT)	*ppos = (AMT)

	#define	PCI_PRESENT()	pci_present()

	#define	PARM_STR(VAR, INIT, DESC) \
		static char *VAR = INIT; \
		MODULE_PARM(VAR, "s"); \
		MODULE_PARM_DESC(VAR, DESC);

	#define	PARM_INT(VAR, INIT, DESC) \
		static int VAR = INIT; \
		MODULE_PARM(VAR, "i"); \
		MODULE_PARM_DESC(VAR, DESC);

	#define	PARM_INTA(VAR, DIM, INIT, DESC) \
		static int VAR[DIM] = INIT; \
		MODULE_PARM(VAR, "1-" #DIM "i"); \
		MODULE_PARM_DESC(VAR, DESC);

	#define	PARM_ULONG(VAR, INIT, DESC) \
		static ulong VAR = INIT; \
		MODULE_PARM(VAR, "l"); \
		MODULE_PARM_DESC(VAR, DESC);

	#define SPINLOCK_DECLARE(VAR)	spinlock_t VAR
	#define SPINLOCK_INIT(x)	spin_lock_init(&(x))

	#define DGRP_LOCK(x,y)		spin_lock_irqsave(&(x), y);
	#define DGRP_UNLOCK(x,y)	spin_unlock_irqrestore(&(x), y);

	#define TERMIOS_LINE_B4_CC	0

	#define DGRP_USE_COUNT		GET_USE_COUNT(&__this_module)

	#define DIGI_MUTEX_INITIALIZER(mutex)  __MUTEX_INITIALIZER(mutex)

	#define PROC_DE_GET_COUNT(deP) (atomic_read(&((deP)->count)))
	#define PROC_DE_OPS_INIT(deP,iops,fops) \
		{ (deP)->proc_iops = (iops); \
		  (deP)->proc_fops = (fops); }

	typedef wait_queue_t		WAITQ;
	typedef wait_queue_head_t	WAITQ_HEAD;

	/*
	 *  In some revisions within the 2.4 kernel series, there is a patch
	 *  which changes the behavior of a failed open.  In 2.0 and 2.2 and
	 *  most 2.4 revisions, a failed open will be followed _always_ by
	 *  a call to the driver's close routine.  In some 2.4 revisions,
	 *  the close will not be called (and therefore driver use counts
	 *  will be too high, and ports may become unusable).
	 *
	 *  In the case that the ALT_FAIL_OPEN code is allowed to exist,
	 *  some new parameters are required, like ALT_FAIL_OPEN_DEFAULT.
	 */
	#define ALLOW_ALT_FAIL_OPEN 1
	#define ALT_FAIL_OPEN_DEFAULT 0

#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2,1,0)

	#include <asm/uaccess.h>
	#include <linux/poll.h>

	#define IOREMAP(ADDR, LEN)		ioremap(ADDR, LEN)
	#define IOUNMAP(ADDR)			iounmap(ADDR)
	#define COPY_FROM_USER(DST,SRC,LEN)	copy_from_user(DST,SRC,LEN)
	#define COPY_TO_USER(DST,SRC,LEN)	copy_to_user(DST,SRC,LEN)
	#define GET_USER(A1,A2)			get_user(A1,(unsigned int *)A2)
	#define PUT_USER(A1,A2)			put_user(A1,(unsigned long *)A2)

	#define	READ_PROTO \
		struct file *file, char *buf, size_t count, loff_t *ppos
	#define	READ_ARGS	file, buf, count, ppos
	#define	READ_RETURN_T	ssize_t

	#define	WRITE_PROTO \
		struct file *file, const char *buf, size_t count, loff_t *ppos
	#define	WRITE_ARGS	file, buf, count, ppos
	#define	WRITE_RETURN_T	ssize_t

	#define SELECT_NAME	poll
	#define SELECT_PROTO \
		struct file *file, struct poll_table_struct *table
	#define SELECT_ARGS	file, table
	#define SELECT_RETURN_T	unsigned int

	#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,2,15)\
		&& LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0)
	#define SERIAL_HAVE_POLL_WAIT 1
		/* This allows the driver to wake up select or poll processes
		 * when write space becomes available.  Only later 2.2.x
		 * kernels require this 8-21-2001
		*/
	#endif

	#define	CLOSE_RETURN_T	int
	#define	CLOSE_RETURN(X)	return(X)

	#define	PARM_I_RDEV	file->f_dentry->d_inode->i_rdev
	#define	PARM_GEN_IP	file->f_dentry->d_inode->u.generic_ip
	#define PTR_POS()	ppos
	#define	GET_POS()	*ppos
	#define	ADD_POS(AMT)	*ppos += (AMT)
	#define	SET_POS(AMT)	*ppos = (AMT)

	#define	PCI_PRESENT()	pci_present()

	#define	PARM_STR(VAR, INIT, DESC) \
		static char *VAR = INIT; \
		MODULE_PARM(VAR, "s"); \
		MODULE_PARM_DESC(VAR, DESC);

	#define	PARM_INT(VAR, INIT, DESC) \
		static int VAR = INIT; \
		MODULE_PARM(VAR, "i"); \
		MODULE_PARM_DESC(VAR, DESC);

	#define	PARM_INTA(VAR, DIM, INIT, DESC) \
		static int VAR[DIM] = INIT; \
		MODULE_PARM(VAR, "1-" #DIM "i"); \
		MODULE_PARM_DESC(VAR, DESC);

	#define	PARM_ULONG(VAR, INIT, DESC) \
		static ulong VAR = INIT; \
		MODULE_PARM(VAR, "l"); \
		MODULE_PARM_DESC(VAR, DESC);

	#define SPINLOCK_DECLARE(VAR)	spinlock_t VAR
	#define SPINLOCK_INIT(x)	spin_lock_init(&(x))

	#define DGRP_LOCK(x,y)		spin_lock_irqsave(&(x), y);
	#define DGRP_UNLOCK(x,y)	spin_unlock_irqrestore(&(x), y);

	#define TERMIOS_LINE_B4_CC	0

	#define DGRP_USE_COUNT		GET_USE_COUNT(&__this_module)

	#define DIGI_MUTEX_INITIALIZER(mutex)  MUTEX

	#define PROC_DE_GET_COUNT(deP) ((deP)->count)
	#define PROC_DE_OPS_INIT(deP,iops,fops) { (deP)->ops = (iops); }

	typedef struct wait_queue	WAITQ;
	typedef struct wait_queue *	WAITQ_HEAD;

	#if LINUX_VERSION_CODE <= KERNEL_VERSION(2,2,17)
		/* starting at 2.2.18 these macros are included in the
		 * kernel header files
		 */
		#define init_MUTEX(mutexP)	{ *(mutexP) = MUTEX ; }
		#define DECLARE_WAITQUEUE(w,c)	WAITQ w = { c, NULL }
		#define init_waitqueue_head(qptr) { *qptr = NULL; }
	#endif

	#define ALLOW_ALT_FAIL_OPEN 0

#else

	#include <linux/bios32.h>
	#include <asm/param.h>

	#define __USE_OLD_SELECT__

	#ifndef _POSIX_VDISABLE
	#define _POSIX_VDISABLE                 '\0'
	#endif

	#define signal_pending(C)	((C)->signal & ~((C)->blocked))

	#define IOREMAP(ADDR, LEN)		vremap(ADDR, LEN)
	#define IOUNMAP(ADDR)			vfree(ADDR)
	#define COPY_FROM_USER(DST,SRC,LEN)	memcpy_fromfs(DST,SRC,LEN)
	#define COPY_TO_USER(DST,SRC,LEN)	memcpy_tofs(DST,SRC,LEN)
	#define GET_USER(A1,A2)		A1 = get_fs_long((unsigned long *) A2)
	#define PUT_USER(A1,A2)		put_fs_long(A1, (unsigned long *) A2)

	#define	READ_PROTO \
		struct inode *inode, struct file *file, char *buf, int count
	#define	READ_ARGS	inode, file, buf, count
	#define	READ_RETURN_T	int

	#define	WRITE_PROTO \
		struct inode *inode,struct file *file,const char *buf, int count
	#define	WRITE_ARGS	inode, file, buf, count
	#define	WRITE_RETURN_T	int

	#define SELECT_NAME	select
	#define SELECT_PROTO \
		struct inode *inode,struct file *file,int mode,select_table *table
	#define SELECT_ARGS	inode, file, mode, table
	#define SELECT_RETURN_T	int

	#define	CLOSE_RETURN_T	void
	#define	CLOSE_RETURN(X)	return

	#define	PARM_I_RDEV	inode->i_rdev
	#define	PARM_GEN_IP	inode->u.generic_ip
	#define	PTR_POS()	&(file->f_pos)
	#define	GET_POS()	file->f_pos
	#define	ADD_POS(AMT)	file->f_pos += (AMT)
	#define	SET_POS(AMT)	file->f_pos = (AMT)

	#define	PCI_PRESENT()	pcibios_present()

	#ifndef MODULE_PARM
		#define MODULE_AUTHOR(NAME)
		#define MODULE_DESCRIPTION(DESC)
		#define MODULE_SUPPORTED_DEVICE(DEV)
		#define MODULE_PARM(VAR,TYPE)
		#define MODULE_PARM_DESC(VAR,DESC)
	#endif

	#define	PARM_STR(VAR,INIT,DESC)		static char *VAR = INIT;
	#define	PARM_INT(VAR,INIT,DESC)		static int VAR = INIT;
	#define	PARM_INTA(VAR,DIM,INIT,DESC)	static int VAR[DIM] = INIT;
	#define	PARM_ULONG(VAR,INIT,DESC)	static ulong VAR = INIT;

	#define SPINLOCK_DECLARE(VAR)	long VAR
	#define SPINLOCK_INIT(x)	((void) 0)

	#define DGRP_LOCK(x,y)		do { save_flags(y); cli(); } while(0)
	#define DGRP_UNLOCK(x,y)	do { restore_flags(y); } while(0)

	#define TERMIOS_LINE_B4_CC	1

	#define DGRP_USE_COUNT		mod_use_count_

	#define init_MUTEX(mutexP)	{ *(mutexP) = MUTEX ; }
	#define DIGI_MUTEX_INITIALIZER(mutex)  MUTEX

	#define PROC_DE_GET_COUNT(deP) 0
	#define PROC_DE_OPS_INIT(deP,iops,fops) { (deP)->ops = (iops); }

	typedef struct wait_queue	WAITQ;
	typedef struct wait_queue *	WAITQ_HEAD;
	#define DECLARE_WAITQUEUE(w,c)	WAITQ w = { c, NULL }
	#define init_waitqueue_head(qptr) { *qptr = NULL; }

	#define ALLOW_ALT_FAIL_OPEN 0

#endif

#define	MIN(a,b)	((a) < (b) ? (a) : (b))
#define	MAX(a,b)	((a) > (b) ? (a) : (b))

#endif /* __LINUX_VER_FIX_H */
